@@ -14,7 +14,7 @@ test_that("core_create works", {
   
   # write files in preparation
   path <- sprintf("~/solr-5.4.1/server/solr/%s/conf", core_name)
-  dir.create(path, recursive = TRUE)
+  dir.create(path, recursive = TRUE, showWarnings = FALSE)
   files <- list.files("~/solr-5.4.1/server/solr/configsets/data_driven_schema_configs/conf/", full.names = TRUE)
   invisible(file.copy(files, path, recursive = TRUE))
   
