@@ -6,21 +6,20 @@ test_that("solr_mlt works", {
   solr_connect('http://api.plos.org/search', verbose=FALSE)
 
   a <- solr_mlt(q='*:*', mlt.count=2, mlt.fl='abstract', fl='score', fq="doc_type:full")
-  # b <- solr_mlt(q='*:*', rows=2, mlt.fl='title', mlt.mindf=1, mlt.mintf=1, fl='alm_twitterCount', base=url, key=key)
   c <- solr_mlt(q='ecology', mlt.fl='abstract', fl='title', rows=5)
 
   out <- solr_mlt(q='ecology', mlt.fl='abstract', fl='title', rows=2, raw=TRUE, wt="xml")
-  library("XML")
-  outxml <- xmlParse(out)
+  library("xml2")
+  outxml <- read_xml(unclass(out))
   outdf <- solr_parse(out, "df")
 
   # correct dimensions
-  expect_that(dim(a$docs), equals(c(10,2)))
-  expect_that(dim(c$docs), equals(c(5,2)))
-  expect_that(length(c$mlt), equals(4))
+  expect_equal(dim(a$docs), c(10,2))
+  expect_equal(dim(c$docs), c(5, 2))
+  expect_equal(length(c$mlt), 5)
 
-  expect_that(length(outxml), equals(1))
-  expect_that(dim(outdf), equals(c(12,2)))
+  expect_equal(length(outxml), 2)
+  expect_equal(dim(outdf$mlt[[1]]), c(5, 5))
 
   # correct classes
   expect_is(a, "list")
@@ -30,6 +29,7 @@ test_that("solr_mlt works", {
   #   expect_is(b$mlt, "data.frame")
   expect_is(c$docs, "data.frame")
 
-  expect_is(outxml, "XMLInternalDocument")
-  expect_is(outdf, "data.frame")
+  expect_is(outxml, "xml_document")
+  expect_is(outdf, "list")
+  expect_is(outdf$mlt[[1]], "data.frame")
 })
